IonLocator class
A lightweight and synchronous Service Locator inspired by ASP.NET DI, custom-built for the Ionex ecosystem.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
addLazySingleton<
T extends Object> (T factory()) → void - Registers a dependency as a Lazy Singleton.
-
addSingleton<
T extends Object> (T instance) → void - Registers an already existing instance as a Singleton
-
addTransient<
T extends Object> (T factory()) → void - Registers a dependency as a Transient (Factory).
-
get<
T extends Object> () → T -
Retrieves the registered instance of type
T. -
reset(
) → void - Clears all registrations from the locator.