reset static method
Clears all registrations from the locator.
Essential for resetting the state between unit test executions.
Implementation
@visibleForTesting
static void reset() {
_factories.clear();
_singletons.clear();
}
Clears all registrations from the locator.
Essential for resetting the state between unit test executions.
@visibleForTesting
static void reset() {
_factories.clear();
_singletons.clear();
}